@@ -8,20 +8,22 @@ use Log::Dump;
 use Scalar::Util qw( blessed );
 
 use overload
-  '""'  => sub { shift->path },
-  'cmp' => sub { return "$_[0]" cmp "$_[1]" },
-  '*{}' => sub { shift->_handle };
+  '""'   => sub { shift->path },
+  'cmp'  => sub { return "$_[0]" cmp "$_[1]" },
+  'bool' => sub { shift->_boolify },
+  '*{}'  => sub { shift->_handle };
 
 sub new {
   my $class = shift;
   my $self  = bless {}, $class;
 
-  $self->_initialize(@_);
+  $self->_initialize(@_) or return;
 
   $self;
 }
 
-sub _initialize {}
+sub _initialize {1}
+sub _boolify {1}
 
 sub _class {
   my ($self, $type) = @_;
@@ -39,13 +41,13 @@ sub _related {
   my $item;
   if ( @parts && $parts[0] eq '..' ) { # parent
     require File::Basename;
-    $item = $class->new( File::Basename::dirname($self->absolute) );
+    $item = $class->new( File::Basename::dirname($self->_absolute) );
   }
   elsif ( @parts && File::Spec->file_name_is_absolute($parts[0]) ) {
     $item = $class->new( @parts );
   }
   else {
-    $item = $class->new( $self->absolute, @parts );
+    $item = $class->new( $self->_absolute, @parts );
   }
   foreach my $key ( grep /^_/, keys %{ $self } ) {
     $item->{$key} = $self->{$key};
@@ -65,16 +67,27 @@ sub _handle { shift->{handle} }
 
 sub path {
   my $self = shift;
-  return ( $self->is_absolute ) ? $self->absolute : $self->relative;
+  return ( $self->is_absolute ) ? $self->_absolute : $self->_relative;
 }
 
 sub stringify { shift->path }
 
 sub is_dir      { shift->{is_dir} }
-sub is_open     { shift->{handle}      ? 1 : 0 }
-sub is_absolute { shift->{_absolute}   ? 1 : 0 }
+sub is_open     { shift->{handle} ? 1 : 0 }
+sub is_absolute {
+  my $self = shift;
+  $self->{_absolute} && !$self->{_base} ? 1 : '';
+}
 
-sub absolute {
+sub resolve {
+  my $self = shift;
+  Carp::croak $! unless -e $self->{path};
+  $self->{path} = $self->_unixify(Cwd::realpath($self->{path}));
+  $self->{_absolute} = File::Spec->file_name_is_absolute($self->{path});
+  $self;
+}
+
+sub _absolute {
   my ($self, %options) = @_;
 
   my $path = File::Spec->canonpath( $self->{path} );
@@ -91,12 +104,12 @@ sub absolute {
   }
 }
 
-sub relative {
+sub _relative {
   my $self = shift;
-  my $base = shift if @_ % 2;
+  my $base = @_ % 2 ? shift : undef;
   my %options = @_;
 
-  $base ||= $options{base};
+  $base ||= $options{base} || $self->{_base};
 
   my $path = File::Spec->abs2rel( $self->{path}, $base );
      $path = $self->_unixify($path) unless $options{native};
@@ -104,31 +117,34 @@ sub relative {
   $path;
 }
 
+sub absolute { shift->_absolute(@_) }
+sub relative { shift->_relative(@_) }
+
 sub parent { shift->_related( dir => '..' ); }
 
 sub unlink {
   my $self = shift;
 
   $self->close if $self->is_open;
-  unlink $self->absolute if $self->exists;
+  unlink $self->_absolute if $self->exists;
 }
 
 sub exists {
   my $self = shift;
 
-  -e $self->absolute ? 1 : 0;
+  -e $self->_absolute ? 1 : 0;
 }
 
 sub is_writable {
   my $self = shift;
 
-  -w $self->absolute ? 1 : 0;
+  -w $self->_absolute ? 1 : 0;
 }
 
 sub is_readable {
   my $self = shift;
 
-  -r $self->absolute ? 1 : 0;
+  -r $self->_absolute ? 1 : 0;
 }
 
 sub copy_to {
@@ -143,7 +159,7 @@ sub copy_to {
   $destination = $class->new( "$destination" );
 
   require File::Copy::Recursive;
-  File::Copy::Recursive::rcopy( $self->absolute, $destination->absolute )
+  File::Copy::Recursive::rcopy( $self->_absolute, $destination->_absolute )
     or do { $self->log( error =>  $! ); return; };
 
   $self;
@@ -163,10 +179,10 @@ sub move_to {
   $self->close if $self->is_open;
 
   require File::Copy::Recursive;
-  File::Copy::Recursive::rmove( $self->absolute, $destination->absolute )
+  File::Copy::Recursive::rmove( $self->_absolute, $destination->_absolute )
     or do { $self->log( error =>  $! ); return; };
 
-  $self->{path} = $destination->absolute;
+  $self->{path} = $destination->_absolute;
 
   $self;
 }
@@ -184,10 +200,10 @@ sub rename_to {
 
   $self->close if $self->is_open;
 
-  rename $self->absolute => $destination->absolute
+  rename $self->_absolute => $destination->_absolute
     or do { $self->log( error => $! ); return; };
 
-  $self->{path} = $destination->absolute;
+  $self->{path} = $destination->_absolute;
 
   $self;
 }
@@ -245,6 +261,10 @@ returns if the path you passed to the constructor was absolute or not (note that
 
 returns if the object represents directory or not.
 
+=head2 resolve
+
+does a physical cleanup of the path with L<Cwd::realpath>, that means, resolves a symbolic link if necessary. Note that this method may croak (when the path does not exist).
+
 =head2 copy_to
 
 copies the file/directory to the destination by C<File::Copy::copy>.
